@@ -1,11 +1,11 @@
 import grequests
 
 def fetch(url):
-    return grequests.get('https://graph.facebook.com/', params={'ids': url})
+    return grequests.get('https://graph.facebook.com/', params={'id': url})
 
 def parse(response):
     if response.status_code != 200:
         raise IOError()
 
-    data = response.json().values()[0]
+    data = response.json()
     return data['shares']
\ No newline at end of file
